@@ -1,6 +1,6 @@
-from http import MediaType
+from django_conneg.conneg import Renderer
 
-def renderer(format, mimetypes=(), priority=0, name=None):
+def renderer(format, mimetypes=(), priority=0, name=None, test=None):
     """
     Decorates a view method to say that it renders a particular format and mimetypes.
 
@@ -19,9 +19,5 @@ def renderer(format, mimetypes=(), priority=0, name=None):
     """
 
     def g(f):
-        f.is_renderer = True
-        f.format = format
-        f.mimetypes = set(MediaType(mimetype, priority) for mimetype in mimetypes)
-        f.name = name
-        return f
-    return g
\ No newline at end of file
+        return Renderer(f, format, mimetypes, priority, name, test)
+    return g
